@@ -19,19 +19,21 @@
 版权持有人不对 DrissionPage 可能存在的缺陷导致的任何损失负任何责任。
 """
 
-from AutoChrome.custom_types import *
+from AutoChrome.utils.custom_types import *
 from AutoChrome.auto_chrome import AutoChrome
-from AutoChrome.chrome_downloader import ChromeDownloader
+from AutoChrome.utils.chrome_downloader import ChromeDownloader
 
 # https://drissionpage.cn/get_start/import/
+
+import DrissionPage
 from DrissionPage import *
+from DownloadKit import *
 from DrissionPage.items import *
 from DrissionPage.errors import *
 from DrissionPage.common import *
-from DownloadKit import *
 
 # 版本号
-VERSION = "0.0.3"
+VERSION = "0.0.8"
 # 作者
 AUTHOR = "Xiaoqiang"
 # 邮箱
@@ -55,4 +57,5 @@ __all__ = [
     "EMAIL",
     "AutoChrome",
     "ChromeDownloader",
+    "DrissionPage",
 ]
